==> nextcloud-20.0.8p0.tgz: nextcloud/apps/weather_status/l10n/cs.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Neznámá adresa",
    "No result." : "Bez výsledku.",
    "Malformed JSON data." : "Nesprávně formátovaná JSON data.",
    "Error" : "Chyba",
    "Weather status" : "Stav počasí",
    "Weather status in your dashboard" : "Stav počasí ve vašem přehledu",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Napojení stavu počasí pro aplikaci Přehled.\n    Polohu uživatele je možné zjistit automaticky nebo zadat ručně. Poté je zobrazována předpověď na příštích 6 hodin.\n    Tento stav je také možné začlenit do ostatních míst, jako například Kalendář.",
    "Detect location" : "Zjistit polohu",
    "Set custom address" : "Nastavit uživatelsky určenou adresu",
    "Favorites" : "Oblíbené",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Jasné nebe v {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Zataženo v {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Jasno v {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Bezmračná noc v {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Polojasno v {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mlhavo v {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Drobný déšť v {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Désť v {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Hustý déšť {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Přeháňky v {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lehké přeháňky v {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Vydatné deště v {time}",
    "More weather for {adr}" : "Více o počasí pro {adr}",
    "Loading weather" : "Načítá se počasí",
    "Set location for weather" : "Nastavit polohu pro předpovídání počasí",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add as favorite" : "Přidat jako oblíbené",
    "You are not logged in." : "Nejste přihlášení.",
    "There was an error getting the weather status information." : "Při získávání informací o stavu počasí došlo k chybě.",
    "No weather information found" : "Nenalezeny žádné informace o počasí",
    "Location not found" : "Umístění nenalezeno",
    "There was an error setting the location address." : "Došlo k chybě při nastavování adresy umístění.",
    "There was an error setting the location." : "Došlo k chybě při nastavování umístění.",
    "There was an error saving the mode." : "Při ukládání režimu došlo k chybě.",
    "There was an error using personal address." : "Došlo k chybě při použití osobní adresy.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Napojení stavu počasí pro aplikaci Přehled.\n    Polohu uživatele je možné zjistit automaticky nebo zadat ručně. Poté je zobrazována předpověď na příštích 6 hodin.\n    Tento stav je také možné začlenit do ostatních míst, jako například Kalendář."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-21.0.3.tgz: nextcloud/apps/weather_status/l10n/cs.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Neznámá adresa",
    "No result." : "Bez výsledku.",
    "Malformed JSON data." : "Nesprávně formátovaná JSON data.",
    "Error" : "Chyba",
    "Weather status" : "Stav počasí",
    "Weather status in your dashboard" : "Stav počasí ve vašem přehledu",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Napojení stavu počasí pro aplikaci Přehled.\n    Polohu uživatele je možné zjistit automaticky nebo zadat ručně. Poté je zobrazována předpověď na příštích 6 hodin.\n    Tento stav je také možné začlenit do ostatních míst, jako například Kalendář.",
    "Detect location" : "Zjistit polohu",
    "Set custom address" : "Nastavit uživatelsky určenou adresu",
    "Favorites" : "Oblíbené",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Jasná obloha v {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Zataženo v {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Krásný den v {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Bezmračná noc v {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Polojasno v {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mlhavo v {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Drobný déšť v {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Désť v {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Hustý déšť {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Přeháňky v {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lehké přeháňky v {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Vydatné deště v {time}",
    "More weather for {adr}" : "Více o počasí pro {adr}",
    "Loading weather" : "Načítá se počasí",
    "Set location for weather" : "Nastavit místo pro které předpovídat počasí",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add as favorite" : "Přidat jako oblíbené",
    "You are not logged in." : "Nejste přihlášení.",
    "There was an error getting the weather status information." : "Při získávání informací o stavu počasí došlo k chybě.",
    "No weather information found" : "Nenalezeny žádné informace o počasí",
    "Location not found" : "Umístění nenalezeno",
    "There was an error setting the location address." : "Došlo k chybě při nastavování adresy umístění.",
    "There was an error setting the location." : "Při nastavování umístění došlo k chybě.",
    "There was an error saving the mode." : "Při ukládání režimu došlo k chybě.",
    "There was an error using personal address." : "Při použití osobní adresy došlo k chybě.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Napojení stavu počasí pro aplikaci Přehled.\n    Polohu uživatele je možné zjistit automaticky nebo zadat ručně. Poté je zobrazována předpověď na příštích 6 hodin.\n    Tento stav je také možné začlenit do ostatních míst, jako například Kalendář."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
